#!/bin/sh
################################################
#
# Service Integration Bus Explorer launch script
# Copyright (C) IBM Corp. 2006
#
# This script will launch the Service Integration Bus Explorer.
# Before running this script, please ensure that your environment
# variables have been customized for your system in the 'env.sh'
# script.
#
################################################


# Set up the environment
. ./env.sh

# Check the environment variable are all correct
if test ! -d $WAS
then
  echo "** WAS environment variable has not been set correctly **"
  echo ""
  echo "This variable is set in the 'env.sh' script and should point to the directory"
  echo "containing your WebSphere Application Server installation."
  echo "For example, /opt/IBM/WebSphere/AppServer."
  exit
fi

if test ! -f $WAS/java/bin/java
then
  echo "** WAS environment variable has not been set correctly **"
  echo ""
  echo "This variable is set in the 'env.sh' script and should point to the directory"
  echo "containing your WebSphere Application Server installation. While the variable "
  echo "does indeed point to a valid directory, the Java Virtual Machine cannot be "
  echo "found and this is needed to successfully run the tool."
  echo "Verify that the WAS environment variable has been set correctly."
  echo "For example, /opt/IBM/WebSphere/AppServer."
  exit
fi

if test ! -d $SWTJARS
then
  echo "** SWTJARS environment variable has not been set correctly **"
  echo ""
  echo "This variable is set in the 'env.sh' script and should point to the directory"
  echo "containing the downloaded SWT libraries."
  exit
fi

if test ! -d $CUR
then 
  echo "** CUR environment variable has not been set correctly **"
  echo ""
  echo "This variable is set in the 'env.sh' script and should point to the directory"
  echo "containing the 'explorer.jar' file."
  exit
fi

export PATH=$CUR:$SWTJARS:$PATH
export LD_LIBRARY_PATH=$SWTJARS
export CLASSPATH=$SWTJARS/swt.jar:$CUR/updater.jar:$CUR/explorer.jar

# Run using the WAS JVM
$WAS/java/bin/java -Dwas.install.root=$WAS -Djava.ext.dirs=$WAS/plugins:$WAS/plugins/com.ibm.ws.security.crypto_6.1.0:$WAS/lib:$WAS/installedChannels:$WAS/java/jre/lib/ext com.ibm.ws.sib.tools.explorer.SIBExplorer $*
